@@ -30,8 +30,10 @@ from thoth.adviser.enums import RecommendationType
 from thoth.adviser.enums import DecisionType
 from thoth.adviser.pipeline_builder import PipelineBuilderContext
 from thoth.adviser.prescription.v1 import UnitPrescription
-from thoth.adviser.prescription.v1.schema import PRESCRIPTION_UNIT_SHOULD_INCLUDE_SCHEMA
-from thoth.adviser.prescription.v1.schema import PRESCRIPTION_UNIT_SHOULD_INCLUDE_RUNTIME_ENVIRONMENTS_SCHEMA
+from thoth.adviser.prescription.v1.schema import (
+    PRESCRIPTION_UNIT_SHOULD_INCLUDE_SCHEMA,
+    PRESCRIPTION_UNIT_SHOULD_INCLUDE_RUNTIME_ENVIRONMENTS_SCHEMA,
+)
 from thoth.common import get_justification_link as jl
 from thoth.common import RuntimeEnvironment
 
@@ -213,6 +215,43 @@ class TestUnitPrescription(AdviserTestCase):
         builder_context.should_receive("is_included").with_args(UnitPrescription).and_return(False).once()
         assert UnitPrescription._should_include_base(builder_context) == include
 
+    @pytest.mark.parametrize(
+        "authenticated,env_authenticated,include",
+        [
+            (True, True, True),
+            (True, False, False),
+            (False, False, True),
+            (False, True, False),
+            (None, False, True),
+            (None, True, True),
+        ],
+    )
+    def test_should_include_authentication(
+        self,
+        builder_context: PipelineBuilderContext,
+        authenticated: Optional[bool],
+        env_authenticated: bool,
+        include: bool,
+    ) -> None:
+        """Test including a pipeline unit based on authentication."""
+        should_include_dict = {"adviser_pipeline": True}
+        if authenticated is not None:
+            should_include_dict["authenticated"] = authenticated
+
+        builder_context.recommendation_type = RecommendationType.LATEST
+        builder_context.decision_type = None
+
+        assert builder_context.is_adviser_pipeline()
+        builder_context.authenticated = env_authenticated
+
+        PRESCRIPTION_UNIT_SHOULD_INCLUDE_SCHEMA(should_include_dict)
+        UnitPrescription._PRESCRIPTION = {
+            "name": "SomePrescriptionUnitName",
+            "should_include": should_include_dict,
+        }
+        builder_context.should_receive("is_included").with_args(UnitPrescription).and_return(False).once()
+        assert UnitPrescription._should_include_base(builder_context) == include
+
     @pytest.mark.parametrize(
         "decision_type,allowed_decision_types,include",
         [
@@ -359,6 +398,35 @@ class TestUnitPrescription(AdviserTestCase):
                 False,
             ),
             # CPU/GPU.
+            (
+                {"hardware": [{"cpu_flags": ["avx2"]}]},
+                {"hardware": {"cpu_family": 9999, "cpu_model": 8888}},
+                False,
+            ),
+            (
+                {"hardware": [{"cpu_flags": ["avx2"]}]},
+                {"hardware": {"cpu_family": 6, "cpu_model": int("0x5", base=16)}},
+                True,
+            ),
+            (
+                {"hardware": [{"cpu_flags": {"not": ["avx2"]}}]},
+                {"hardware": {"cpu_family": 6, "cpu_model": int("0x5", base=16)}},
+                False,
+            ),
+            (
+                {"hardware": [{"cpu_flags": ["avx2", "avx512"], "cpu_families": [4, 5, 6], "cpu_models": [4, 5, 6]}]},
+                {"hardware": {"cpu_family": 6, "cpu_model": int("0x5", base=16)}},
+                True,
+            ),
+            (
+                {
+                    "hardware": [
+                        {"cpu_flags": {"not": ["avx2", "avx512"]}, "cpu_families": [4, 5, 6], "cpu_models": [4, 5, 6]}
+                    ]
+                },
+                {"hardware": {"cpu_family": 6, "cpu_model": int("0x5", base=16)}},
+                False,
+            ),
             (
                 {"hardware": [{"cpu_families": [1, 2, 3], "cpu_models": [9, 8, 7], "gpu_models": [None, "Some"]}]},
                 {"hardware": {"cpu_family": 1, "cpu_model": 7}},
@@ -539,6 +607,207 @@ class TestUnitPrescription(AdviserTestCase):
         assert builder_context.is_adviser_pipeline()
         assert UnitPrescription._should_include_base(builder_context) == include
 
+    @pytest.mark.parametrize(
+        "prescription_base_images,used_base_image,include",
+        [
+            ([None], None, True),
+            (["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0"], None, False),
+            ([None], "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0", False),
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                True,
+            ),
+            # No tag specified in the prescription.
+            (["quay.io/thoth-station/s2i-thoth-ubi8-py36"], "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0", True),
+            # Tag for any specified.
+            (["quay.io/thoth-station/s2i-thoth-ubi8-py36:*"], "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0", True),
+            # Matching desired releases.
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0*"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                True,
+            ),
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.*"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                True,
+            ),
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0*"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                True,
+            ),
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.*"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                True,
+            ),
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1*"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                True,
+            ),
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v*"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                True,
+            ),
+            # Not matching tag.
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.1",
+                False,
+            ),
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0*"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.1",
+                False,
+            ),
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.*"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.1.0",
+                False,
+            ),
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.*"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v2.0",
+                False,
+            ),
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1*"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v2.0",
+                False,
+            ),
+            # Not matching image.
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py39:v1.0"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0",
+                False,
+            ),
+            (
+                ["quay.io/thoth-station/s2i-thoth-ubi8-py39:v1.*"],
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0",
+                False,
+            ),
+            #
+            # Inverted matching.
+            #
+            ({"not": [None]}, None, False),
+            ({"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0"]}, None, True),
+            ({"not": [None]}, "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0", True),
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                False,
+            ),
+            # No tag specified in the prescription.
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                False,
+            ),
+            # Tag for any specified.
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:*"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                False,
+            ),
+            # Matching desired releases.
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0*"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                False,
+            ),
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.*"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                False,
+            ),
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0*"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                False,
+            ),
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.*"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                False,
+            ),
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1*"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                False,
+            ),
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v*"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0",
+                False,
+            ),
+            # Not matching tag.
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.1",
+                True,
+            ),
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.0*"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.1",
+                True,
+            ),
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0.*"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.1.0",
+                True,
+            ),
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.*"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v2.0",
+                True,
+            ),
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py36:v1*"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v2.0",
+                True,
+            ),
+            # Not matching image.
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py39:v1.0"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0",
+                True,
+            ),
+            (
+                {"not": ["quay.io/thoth-station/s2i-thoth-ubi8-py39:v1.*"]},
+                "quay.io/thoth-station/s2i-thoth-ubi8-py36:v1.0",
+                True,
+            ),
+        ],
+    )
+    def test_should_include_base_images(
+        self,
+        builder_context: PipelineBuilderContext,
+        prescription_base_images: Union[List[Optional[str]], Dict[str, List[Optional[str]]]],
+        used_base_image: Optional[str],
+        include: bool,
+    ) -> None:
+        """Test more sophisticated expressions specifying inclusion base on base images."""
+        UnitPrescription._PRESCRIPTION = {
+            "name": "FooBarName",
+            "should_include": {
+                "adviser_pipeline": True,
+                "runtime_environments": {
+                    "base_images": prescription_base_images,
+                },
+            },
+        }
+        PRESCRIPTION_UNIT_SHOULD_INCLUDE_SCHEMA(UnitPrescription._PRESCRIPTION["should_include"])
+        builder_context.project.runtime_environment.base_image = used_base_image
+
+        builder_context.should_receive("is_included").with_args(UnitPrescription).and_return(False).once()
+
+        assert builder_context.is_adviser_pipeline()
+        assert UnitPrescription._should_include_base(builder_context) == include
+
     @pytest.mark.parametrize(
         "library_usage_expected,library_usage_supplied,include",
         [
