@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2019, 2020 Fridolin Pokorny
+# Copyright(C) 2019 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -69,6 +69,22 @@ tensorflow = "*"
 
 [pipenv]
 allow_prereleases = true
+"""
+
+    _CASE_SELECTIVE_PRERELEASES_ALLOWED_PIPFILE = """
+[[source]]
+url = "https://pypi.org/simple"
+verify_ssl = true
+name = "pypi"
+
+[packages]
+tensorflow = "*"
+
+[pipenv]
+allow_prereleases = true
+
+[thoth.allow_prereleases]
+tensorflow = true
 """
 
     @pytest.mark.parametrize(
@@ -91,7 +107,7 @@ allow_prereleases = true
         builder_context.project = Project.from_strings(self._CASE_DISALLOWED_PIPFILE)
 
         assert builder_context.is_adviser_pipeline()
-        assert CutPreReleasesSieve.should_include(builder_context) == {}
+        assert list(CutPreReleasesSieve.should_include(builder_context)) == [{}]
 
     @pytest.mark.parametrize(
         "recommendation_type",
@@ -113,7 +129,15 @@ allow_prereleases = true
         builder_context.project = Project.from_strings(self._CASE_ALLOWED_PIPFILE)
 
         assert builder_context.is_adviser_pipeline()
-        assert CutPreReleasesSieve.should_include(builder_context) is None
+        assert list(CutPreReleasesSieve.should_include(builder_context)) == []
+
+    def test_not_include_thoth_prereleases_allowed(self, builder_context: PipelineBuilderContext) -> None:
+        """Test not including this pipeline unit."""
+        builder_context.recommendation_type = RecommendationType.LATEST
+        builder_context.project = Project.from_strings(self._CASE_SELECTIVE_PRERELEASES_ALLOWED_PIPFILE)
+
+        assert builder_context.is_adviser_pipeline()
+        assert list(CutPreReleasesSieve.should_include(builder_context)) == []
 
     def test_verify_multiple_should_include(self, builder_context: PipelineBuilderContext) -> None:
         """Verify multiple should_include calls do not loop endlessly."""
