@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2018, 2019, 2020 Fridolin Pokorny
+# Copyright(C) 2018 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -42,6 +42,6 @@ class DependencyMonkeyReport:
         """Add a new response to response listing."""
         self._responses.append({"response": response, "product": product.to_dict()})
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self, *, verbose: bool = False) -> Dict[str, Any]:
         """Convert report to a dict representation suitable for serialization."""
         return {"skipped": self.skipped, "responses": self._responses}
