@@ -18,13 +18,15 @@
 """A base class for prescription based pipeline units."""
 
 import abc
-import re
 import logging
+import re
 from typing import Any
+from typing import Callable
 from typing import Dict
 from typing import Generator
 from typing import List
 from typing import Optional
+from typing import Set
 from typing import Tuple
 from typing import Type
 from typing import TYPE_CHECKING
@@ -36,8 +38,9 @@ from voluptuous import Required
 
 import attr
 
-from thoth.adviser.exceptions import NotAcceptable
+from thoth.adviser.cpu_db import CPUDatabase
 from thoth.adviser.exceptions import EagerStopPipeline
+from thoth.adviser.exceptions import NotAcceptable
 from thoth.adviser.state import State
 from thoth.common import get_justification_link as jl
 from thoth.python import PackageVersion
@@ -46,7 +49,6 @@ from .unit_cache import should_include_cache
 from ...unit import Unit
 
 if TYPE_CHECKING:
-    from typing import Callable
     from ...pipeline_builder import PipelineBuilderContext
 
 
@@ -70,6 +72,72 @@ class _ValueList:
         return not self._list["not"].__contains__(item)
 
 
+class _ValueListBaseImage:
+    """A class that overrides `in` to transparently handle included and excluded base images."""
+
+    # Image name mapped to image tag; the "_not" flag specifies if images were declared as part of "not".
+    __slots__ = ["_images", "_not"]
+
+    def __init__(self, obj: Union[List[Optional[str]], Dict[str, List[Optional[str]]]]) -> None:
+        """Initialize self."""
+        self._images: Dict[Optional[str], Set[str]] = {}
+
+        if isinstance(obj, dict):
+            image_listing = obj["not"]
+            self._not = True
+        else:
+            image_listing = obj
+            self._not = False
+
+        images = []
+        for item in image_listing:
+            if item is None:
+                self._images[None] = {"*"}
+                continue
+
+            images.append(item.rsplit(":", maxsplit=1))
+
+        for image in images:
+            tag_exp_set = self._images.get(image[0])
+            if tag_exp_set is None:
+                tag_exp_set = set()
+                self._images[image[0]] = tag_exp_set
+
+            if len(image) == 1:
+                tag_exp_set.add("*")  # Means any tag.
+                continue
+
+            tag = image[1]
+            tag_exp_set.add(tag)
+
+    def __contains__(self, item: Optional[str]) -> bool:
+        """Check if the given item (base image) is in the provided listing."""
+        if item is None:
+            # Match `None` image in the image listing.
+            if item in self._images:
+                return not self._not
+
+            return self._not
+
+        parts = item.rsplit(":", maxsplit=1)
+        if len(parts) == 1:  # No tag specified.
+            return parts[0] not in self._images if self._not else parts[0] in self._images
+
+        image, tag = parts
+        tag_expressions = self._images.get(image)
+        if not tag_expressions:
+            return self._not
+
+        for tag_exp in tag_expressions:
+            if tag_exp.endswith("*"):
+                if tag.startswith(tag_exp[:-1]):
+                    return not self._not
+            elif tag_exp == tag:
+                return not self._not
+
+        return self._not
+
+
 @attr.s(slots=True)
 class UnitPrescription(Unit, metaclass=abc.ABCMeta):
     """A base class for implementing pipeline units based on prescription supplied."""
@@ -81,6 +149,7 @@ class UnitPrescription(Unit, metaclass=abc.ABCMeta):
             Required("package_name"): str,
             Required("match"): object,
             Required("run"): object,
+            Required("prescription"): Schema({"run": bool}),
         }
     )
 
@@ -118,6 +187,7 @@ class UnitPrescription(Unit, metaclass=abc.ABCMeta):
             "package_name": None,
             "match": self._PRESCRIPTION.get("match", {}),
             "run": self._PRESCRIPTION.get("run", {}),
+            "prescription": {"run": False},
         }
 
     @classmethod
@@ -298,6 +368,14 @@ class UnitPrescription(Unit, metaclass=abc.ABCMeta):
                 )
                 return False
 
+        authenticated = should_include_dict.get("authenticated")
+        if authenticated is not None and authenticated is not builder_context.authenticated:
+            _LOGGER.debug(
+                "%s: Not registering as authentication requirements are not met",
+                unit_name,
+            )
+            return False
+
         labels_expected = should_include_dict.get("labels", {})
         if labels_expected:
             for label_key, value in labels_expected.items():
@@ -363,6 +441,7 @@ class UnitPrescription(Unit, metaclass=abc.ABCMeta):
             # CPU/GPU
             cpu_families = hardware_dict.get("cpu_families")
             cpu_models = hardware_dict.get("cpu_models")
+            cpu_flags = hardware_dict.get("cpu_flags") or []
             gpu_models = hardware_dict.get("gpu_models")
             if cpu_families is not None and hw_used.cpu_family not in _ValueList(cpu_families):
                 _LOGGER.debug("%s: Not matching CPU family used (using %r)", unit_name, hw_used.cpu_family)
@@ -376,6 +455,48 @@ class UnitPrescription(Unit, metaclass=abc.ABCMeta):
                 _LOGGER.debug("%s: Not matching GPU model used (using %r)", unit_name, hw_used.gpu_model)
                 return False
 
+            if cpu_flags:
+                if hw_used.cpu_family is None or hw_used.cpu_model is None:
+                    _LOGGER.debug(
+                        "%s: CPU family (%s) or CPU model (%s) not provided, cannot check CPU flags %r",
+                        unit_name,
+                        hw_used.cpu_family,
+                        hw_used.cpu_model,
+                        cpu_flags,
+                    )
+                    return False
+
+                if isinstance(cpu_flags, dict):
+                    for cpu_flag in cpu_flags["not"]:
+                        if CPUDatabase.provides_flag(hw_used.cpu_family, hw_used.cpu_model, cpu_flag):
+                            _LOGGER.debug(
+                                "%s: CPU flag %r is provided by CPU family %s and CPU model %s, not registering unit",
+                                unit_name,
+                                cpu_flag,
+                                hw_used.cpu_family,
+                                hw_used.cpu_model,
+                            )
+                            return False
+                else:
+                    for cpu_flag in cpu_flags:
+                        if not CPUDatabase.provides_flag(hw_used.cpu_family, hw_used.cpu_model, cpu_flag):
+                            _LOGGER.debug(
+                                "%s: Not matching CPU flag %r for CPU family %s and CPU model %s, not registering unit",
+                                unit_name,
+                                cpu_flag,
+                                hw_used.cpu_family,
+                                hw_used.cpu_model,
+                            )
+                            return False
+
+                _LOGGER.debug(
+                    "%s: Used CPU family %s and CPU model %s provides all CPU flags required %r",
+                    unit_name,
+                    hw_used.cpu_family,
+                    hw_used.cpu_model,
+                    cpu_flags,
+                )
+
         # Software present.
         runtime_used = builder_context.project.runtime_environment
 
@@ -445,7 +566,7 @@ class UnitPrescription(Unit, metaclass=abc.ABCMeta):
             return False
 
         base_images = runtime_environment_dict.get("base_images")
-        if base_images is not None and runtime_used.base_image not in _ValueList(base_images):
+        if base_images is not None and runtime_used.base_image not in _ValueListBaseImage(base_images):
             _LOGGER.debug("%s: Not matching base image used (using %r)", unit_name, runtime_used.base_image)
             return False
 
@@ -766,7 +887,7 @@ class UnitPrescription(Unit, metaclass=abc.ABCMeta):
     def pre_run(self) -> None:
         """Prepare this pipeline unit before running it."""
         self._prepare_justification_link(self.run_prescription.get("stack_info", []))
-        self._stack_info_run = False
+        self._configuration["prescription"]["run"] = False
         super().pre_run()
 
     @staticmethod
@@ -774,20 +895,28 @@ class UnitPrescription(Unit, metaclass=abc.ABCMeta):
         """Yield for every entry stated in the match field."""
         match = unit_prescription.get("match", {})
         run = unit_prescription.get("run", {})
+        prescription_conf = {"run": False}
         if isinstance(match, list):
             for item in match:
                 yield {
                     "package_name": item["package_version"].get("name") if item else None,
                     "match": item,
                     "run": run,
+                    "prescription": prescription_conf,
                 }
         else:
-            yield {"package_name": match["package_version"].get("name") if match else None, "match": match, "run": run}
+            yield {
+                "package_name": match["package_version"].get("name") if match else None,
+                "match": match,
+                "run": run,
+                "prescription": prescription_conf,
+            }
 
     @staticmethod
     def _yield_should_include_with_state(unit_prescription: Dict[str, Any]) -> Generator[Dict[str, Any], None, None]:
         """Yield for every entry stated in the match field."""
         match = unit_prescription.get("match", {})
+        prescription_conf = {"run": False}
         if isinstance(match, list):
             for item in match:
                 match_resolved = item.get("state", {}).get("resolved_dependencies")
@@ -796,6 +925,7 @@ class UnitPrescription(Unit, metaclass=abc.ABCMeta):
                     "package_name": match_resolved[0].get("name") if match_resolved else None,
                     "match": item,
                     "run": unit_prescription["run"],
+                    "prescription": prescription_conf,
                 }
         else:
             match_resolved = match.get("state", {}).get("resolved_dependencies") if match else None
@@ -803,21 +933,25 @@ class UnitPrescription(Unit, metaclass=abc.ABCMeta):
                 "package_name": match_resolved[0].get("name") if match_resolved else None,
                 "match": match,
                 "run": unit_prescription["run"],
+                "prescription": prescription_conf,
             }
 
     def _run_log(self) -> None:
         """Log message specified in the run prescription."""
+        if self._configuration["prescription"]["run"]:
+            # Noop. The prescription was already run.
+            return
+
         log = self.run_prescription.get("log")
         if log:
             _LOGGER.log(level=getattr(logging, log["type"]), msg=f"{self.name}: {log['message']}")
 
     def _run_stack_info(self) -> None:
         """Add stack info if any prescribed."""
-        if self._stack_info_run:
-            # Stack info already reported.
-            return None
+        if self._configuration["prescription"]["run"]:
+            # Noop. The prescription was already run.
+            return
 
-        self._stack_info_run = True
         stack_info = self.run_prescription.get("stack_info")
         if stack_info:
             self.context.stack_info.extend(stack_info)
