@@ -38,9 +38,6 @@ import weakref
 import heapq
 
 import attr
-import matplotlib
-import matplotlib.pyplot as plt
-from matplotlib.font_manager import FontProperties
 from thoth.common import get_justification_link as jl
 from thoth.python import PackageVersion
 from thoth.python import Project
@@ -75,6 +72,7 @@ from .unit import Unit
 from .utils import log_once
 
 if TYPE_CHECKING:
+    import matplotlib
     from .prescription import Prescription  # noqa: F401
 
 
@@ -490,7 +488,7 @@ class Resolver:
 
         return True
 
-    def _run_wraps(self, state: State) -> None:
+    def _run_wraps(self, state: State, *, sort: bool = False) -> None:
         """Run all wraps bound to the current run context."""
         package_wraps = []
         for package_name in state.resolved_dependencies:
@@ -504,6 +502,9 @@ class Resolver:
             except Exception as exc:
                 raise WrapError(f"Failed to run wrap {wrap.name!r} on a final state: {str(exc)}") from exc
 
+        if sort:
+            state.justification.sort(key=lambda i: (i.get("package_name", ""), i["type"], i["message"]))
+
     def _prepare_user_lock_file(self, *, with_devel: bool = True) -> None:
         """Perform operations on the user's lock file required before running the pipeline.
 
@@ -694,6 +695,15 @@ class Resolver:
                 )
                 _LOGGER.warning("%s - see %s", error_msg, jl("unresolved"))
 
+            self.context.stack_info.append(
+                {
+                    "message": "Visit thoth-station/support repository and request analyses of unresolved packages "
+                    "to have them available in recommendations",
+                    "link": "https://tinyurl.com/thoth-unresolved",
+                    "type": "INFO",
+                }
+            )
+
             raise UnresolvedDependencies(
                 "Unable to resolve all direct dependencies", unresolved=unresolved, stack_info=self.context.stack_info
             )
@@ -1274,6 +1284,10 @@ class Resolver:
                 del final_state
         except EagerStopPipeline as exc:
             _LOGGER.info("Stopping pipeline eagerly as per request: %s", exc)
+        except Exception:
+            self.predictor.post_run()
+            self.pipeline.call_post_run()
+            raise
 
         duration = time.monotonic() - start_time
         _LOGGER.info(
@@ -1302,7 +1316,7 @@ class Resolver:
         with Unit.assigned_context(self.context), self.predictor.assigned_context(self.context):
             for state in self._do_resolve_states(with_devel=with_devel, user_stack_scoring=user_stack_scoring):
                 # Always run wraps as raw products are computed.
-                self._run_wraps(state)
+                self._run_wraps(state, sort=True)
                 yield Product.from_final_state(context=self.context, state=state)
 
     def resolve(self, *, with_devel: bool = True, user_stack_scoring: bool = True) -> Report:
@@ -1337,7 +1351,7 @@ class Resolver:
                 raise CannotProduceStack(msg + f" - see {link}", stack_info=self.context.stack_info)
 
             for item in states:
-                self._run_wraps(item[1])
+                self._run_wraps(item[1], sort=True)
 
             report = Report(
                 products=[
@@ -1356,11 +1370,14 @@ class Resolver:
 
             return report
 
-    def plot(self) -> matplotlib.figure.Figure:
+    def plot(self) -> "matplotlib.figure.Figure":
         """Plot history captured during the resolution process."""
         if not self._history:
             raise NoHistoryKept("No history datapoints kept")
 
+        import matplotlib.pyplot as plt
+        from matplotlib.font_manager import FontProperties
+
         x = [i for i in range(len(self._history))]
         y1 = self._history
         y2 = self._history_max
