@@ -25,10 +25,10 @@ from .filter_index import FilterIndexSieve
 from .index_enabled import PackageIndexSieve
 from .legacy_version import LegacyVersionSieve
 from .locked import CutLockedSieve
+from .package_combinations import PackageCombinationsSieve
 from .prereleases import CutPreReleasesSieve
 from .rules import SolverRulesSieve
 from .solved import SolvedSieve
-from .tensorflow import TensorFlow240AVX2IllegalInstructionSieve
 from .tensorflow import TensorFlowAPISieve
 from .thoth_s2i_abi_compat import ThothS2IAbiCompatibilitySieve
 from .thoth_s2i_packages import ThothS2IPackagesSieve
@@ -45,6 +45,7 @@ __all__ = [
     "ConstraintsSieve",
     "SelectiveCutPreReleasesSieve",
     "FilterConfiguredIndexSieve",
+    "PackageCombinationsSieve",
     "PackageIndexConfigurationSieve",
     "CutLockedSieve",
     "PackageIndexSieve",
@@ -54,6 +55,5 @@ __all__ = [
     "ThothS2IPackagesSieve",
     "ThothS2IAbiCompatibilitySieve",
     "FilterIndexSieve",
-    "TensorFlow240AVX2IllegalInstructionSieve",
     "TensorFlowAPISieve",
 ]
